@@ -62,8 +62,12 @@ class Client(BaseClient):
         return self.handle_request(url=self._base_url + EndpointsV2.get_user_info)
 
     @property
-    def token(self) -> str:
-        return self._token
+    def token(self):
+        try:
+            self.get_user_info()
+            return self._token
+        except Exception:
+            return None
 
     @property
     def username(self) -> str:
